@@ -46,7 +46,7 @@ repo_root = pjoin(tmp, 'pyzmq-release')
 sdist_root = pjoin(tmp, 'pyzmq-sdist')
 
 def _py(py):
-    return py_exes.get(py, py)
+    return py_exes[py]
 
 def run(cmd, **kwargs):
     """wrapper around invoke.run that accepts a Popen list"""
@@ -129,7 +129,7 @@ def make_env(py_exe, *packages):
     py = pjoin(env, 'bin', 'python')
     # new env
     if not os.path.exists(py):
-        run('python -m virtualenv {} -p {}'.format(
+        run('virtualenv {} -p {}'.format(
             pipes.quote(env),
             pipes.quote(py_exe),
         ))
@@ -144,12 +144,11 @@ def build_sdist(py, upload=False):
     
     Returns the path to the tarball
     """
-    install(py, 'cython')
     with cd(repo_root):
         cmd = [py, 'setup.py', 'sdist', '--formats=zip,gztar']
-        if upload:
-            cmd.append('upload')
         run(cmd)
+        if upload:
+            run(['twine', 'upload', 'dist/*'])
     
     return glob.glob(pjoin(repo_root, 'dist', '*.tar.gz'))[0]
 
@@ -157,7 +156,7 @@ def build_sdist(py, upload=False):
 def sdist(vs, upload=False):
     clone_repo()
     tag(vs, push=upload)
-    py = make_env('2.7', 'cython')
+    py = make_env('3.5', 'cython', 'twine')
     tarball = build_sdist(py, upload=upload)
     return untar(tarball)
 
@@ -182,19 +181,40 @@ def untar(tarball):
     
     return glob.glob(pjoin(sdist_root, '*'))[0]
 
-def bdist(py, upload=False, wheel=True, egg=False):
+def bdist(py, wheel=True, egg=False):
     py = make_env(py, 'wheel')
     cmd = [py, 'setup.py']
     if wheel:
         cmd.append('bdist_wheel')
     if egg:
         cmd.append('bdist_egg')
-    if upload:
-        cmd.append('upload')
     cmd.append('--zmq=bundled')
     
     run(cmd)
 
+@task
+def manylinux(vs, upload=False):
+    """Build manylinux wheels with Matthew Brett's manylinux-builds"""
+    manylinux = '/tmp/manylinux-builds'
+    if not os.path.exists(manylinux):
+        with cd('/tmp'):
+            run("git clone --recursive https://github.com/minrk/manylinux-builds -b pyzmq")
+    else:
+        with cd(manylinux):
+            run("git pull")
+            run("git submodule update")
+    
+    base_cmd = "docker run --rm -e PYZMQ_VERSIONS='{vs}' -e PYTHON_VERSIONS='{pys}' -v $PWD:/io".format(
+        vs=vs,
+        pys='2.7 3.4 3.5'
+    )
+    with cd(manylinux):
+        run(base_cmd +  " quay.io/pypa/manylinux1_x86_64 /io/build_pyzmqs.sh")
+        run(base_cmd +  " quay.io/pypa/manylinux1_i686 linux32 /io/build_pyzmqs.sh")
+    if upload:
+        py = make_env('3.5', 'twine')
+        run(['twine', 'upload', os.path.join(manylinux, 'wheelhouse', '*')])
+
 @task
 def release(vs, upload=False):
     """Release pyzmq"""
@@ -212,5 +232,9 @@ def release(vs, upload=False):
     
     with cd(path):
         for v in py_exes:
-            bdist(v, upload=upload, wheel=True, egg=(v in egg_pys))
+            bdist(v, wheel=True, egg=(v in egg_pys))
+        if upload:
+            py = make_env('3.5', 'twine')
+            run(['twine', 'upload', 'dist/*'])
 
+    manylinux(vs, upload=upload)
