@@ -16,9 +16,8 @@ from .poll import Poller
 from . import constants
 from .attrsettr import AttributeSetter
 from zmq.error import ZMQError, ZMQBindError
-from zmq.utils import jsonapi
-from zmq.utils.strtypes import bytes,unicode,basestring
-from zmq.utils.interop import cast_int_addr
+from zmq.utils.strtypes import bytes, unicode, basestring
+
 
 from .constants import (
     SNDMORE, ENOTSUP, POLLIN,
@@ -57,6 +56,7 @@ class Socket(SocketBase, AttributeSetter):
     
     """
     _shadow = False
+    _monitor_socket = None
     
     def __init__(self, *a, **kw):
         super(Socket, self).__init__(*a, **kw)
@@ -99,6 +99,7 @@ class Socket(SocketBase, AttributeSetter):
         
         .. versionadded:: 14.1
         """
+        from zmq.utils.interop import cast_int_addr
         address = cast_int_addr(address)
         return cls(shadow=address)
     
@@ -134,6 +135,42 @@ class Socket(SocketBase, AttributeSetter):
     setsockopt = SocketBase.set
     getsockopt = SocketBase.get
     
+    def __setattr__(self, key, value):
+        """override to allow setting zmq.[UN]SUBSCRIBE even though we have a subscribe method"""
+        _key = key.lower()
+        if _key in ('subscribe', 'unsubscribe'):
+            
+            if isinstance(value, unicode):
+                value = value.encode('utf8')
+            if _key == 'subscribe':
+                self.set(zmq.SUBSCRIBE, value)
+            else:
+                self.set(zmq.UNSUBSCRIBE, value)
+            return
+        super(Socket, self).__setattr__(key, value)
+    
+    def subscribe(self, topic):
+        """Subscribe to a topic
+
+        Only for SUB sockets.
+
+        .. versionadded:: 15.3
+        """
+        if isinstance(topic, unicode):
+            topic = topic.encode('utf8')
+        self.set(zmq.SUBSCRIBE, topic)
+    
+    def unsubscribe(self, topic):
+        """Unsubscribe from a topic
+
+        Only for SUB sockets.
+
+        .. versionadded:: 15.3
+        """
+        if isinstance(topic, unicode):
+            topic = topic.encode('utf8')
+        self.set(zmq.UNSUBSCRIBE, topic)
+    
     def set_string(self, option, optval, encoding='utf-8'):
         """set socket options with a unicode object
         
@@ -448,6 +485,7 @@ class Socket(SocketBase, AttributeSetter):
         flags : int
             Any valid send flag
         """
+        from zmq.utils import jsonapi
         msg = jsonapi.dumps(obj, **kwargs)
         return self.send(msg, flags)
 
@@ -466,6 +504,7 @@ class Socket(SocketBase, AttributeSetter):
         obj : Python object
             The Python object that arrives as a message.
         """
+        from zmq.utils import jsonapi
         msg = self.recv(flags)
         return jsonapi.loads(msg, **kwargs)
     
@@ -523,6 +562,14 @@ class Socket(SocketBase, AttributeSetter):
         # safe-guard, method only available on libzmq >= 4
         if zmq.zmq_version_info() < (4,):
             raise NotImplementedError("get_monitor_socket requires libzmq >= 4, have %s" % zmq.zmq_version())
+
+        # if already monitoring, return existing socket
+        if self._monitor_socket:
+            if self._monitor_socket.closed:
+                self._monitor_socket = None
+            else:
+                return self._monitor_socket
+
         if addr is None:
             # create endpoint name from internal fd
             addr = "inproc://monitor.s-%d" % self.FD
@@ -532,9 +579,9 @@ class Socket(SocketBase, AttributeSetter):
         # attach monitoring socket
         self.monitor(addr, events)
         # create new PAIR socket and connect it
-        ret = self.context.socket(zmq.PAIR)
-        ret.connect(addr)
-        return ret
+        self._monitor_socket = self.context.socket(zmq.PAIR)
+        self._monitor_socket.connect(addr)
+        return self._monitor_socket
 
     def disable_monitor(self):
         """Shutdown the PAIR socket (created using get_monitor_socket)
@@ -542,6 +589,7 @@ class Socket(SocketBase, AttributeSetter):
         
         .. versionadded:: 14.4
         """
+        self._monitor_socket = None
         self.monitor(None, 0)
 
 
