@@ -1,31 +1,17 @@
-#-----------------------------------------------------------------------------
-#  Copyright (c) 2010-2012 Brian Granger, Min Ragan-Kelley
-#
-#  This file is part of pyzmq
-#
-#  Distributed under the terms of the New BSD License.  The full license is in
-#  the file COPYING.BSD, distributed as part of this software.
-#-----------------------------------------------------------------------------
-
-#-----------------------------------------------------------------------------
-# Imports
-#-----------------------------------------------------------------------------
+# Copyright (C) PyZMQ Developers
+# Distributed under the terms of the Modified BSD License.
 
 import sys
 from unittest import TestCase
 
-#-----------------------------------------------------------------------------
-# Tests
-#-----------------------------------------------------------------------------
-
 class TestImports(TestCase):
     """Test Imports - the quickest test to ensure that we haven't
     introduced version-incompatible syntax errors."""
-    
+
     def test_toplevel(self):
         """test toplevel import"""
         import zmq
-        
+
     def test_core(self):
         """test core imports"""
         from zmq import Context
@@ -35,25 +21,25 @@ class TestImports(TestCase):
         from zmq import constants
         from zmq import device, proxy
         from zmq import Stopwatch
-        from zmq import ( 
+        from zmq import (
             zmq_version,
             zmq_version_info,
             pyzmq_version,
             pyzmq_version_info,
         )
-    
+
     def test_devices(self):
         """test device imports"""
         import zmq.devices
         from zmq.devices import basedevice
         from zmq.devices import monitoredqueue
         from zmq.devices import monitoredqueuedevice
-    
+
     def test_log(self):
         """test log imports"""
         import zmq.log
         from zmq.log import handlers
-    
+
     def test_eventloop(self):
         """test eventloop imports"""
         import zmq.eventloop
@@ -61,13 +47,19 @@ class TestImports(TestCase):
         from zmq.eventloop import zmqstream
         from zmq.eventloop.minitornado.platform import auto
         from zmq.eventloop.minitornado import ioloop
-    
+
     def test_utils(self):
         """test util imports"""
         import zmq.utils
         from zmq.utils import strtypes
         from zmq.utils import jsonapi
-    
 
+    def test_ssh(self):
+        """test ssh imports"""
+        from zmq.ssh import tunnel
+
+    def test_decorators(self):
+        """test decorators imports"""
+        from zmq.decorators import context, socket
 
 
