@@ -29,6 +29,8 @@ new_in = {
         'MAX_SOCKETS_DFLT',
         
         # socket opts
+        'IPV4ONLY',
+        'LAST_ENDPOINT',
         'ROUTER_BEHAVIOR',
         'ROUTER_MANDATORY',
         'FAIL_UNROUTABLE',
@@ -104,7 +106,6 @@ new_in = {
         'GSSAPI_SERVICE_PRINCIPAL',
         'GSSAPI_PLAINTEXT',
         'HANDSHAKE_IVL',
-        'IDENTITY_FD',
         'XPUB_NODROP',
         'SOCKS_PROXY',
         
@@ -114,8 +115,37 @@ new_in = {
         
         # security
         'GSSAPI',
-        
     ],
+    (4,2,0) : [
+        # socket types
+        'CLIENT',
+        'SERVER',
+        
+        # ctx options
+        'BLOCKY',
+        
+        # socket options
+        'XPUB_MANUAL',
+        'XPUB_WELCOME_MSG',
+        'STREAM_NOTIFY',
+        'INVERT_MATCHING',
+        'HEARTBEAT_IVL',
+        'HEARTBEAT_TTL',
+        'HEARTBEAT_TIMEOUT',
+        'XPUB_VERBOSER',
+        'CONNECT_TIMEOUT',
+        'TCP_MAXRT',
+        'THREAD_SAFE',
+        'MULTICAST_MAXTPDU',
+        'VMCI_BUFFER_SIZE',
+        'VMCI_BUFFER_MIN_SIZE',
+        'VMCI_BUFFER_MAX_SIZE',
+        'VMCI_CONNECT_TIMEOUT',
+        'USE_FD',
+        
+        # polling
+        'POLLPRI',
+    ]
 }
 
 
@@ -147,6 +177,7 @@ base_names = [
     'POLLIN',
     'POLLOUT',
     'POLLERR',
+    'POLLPRI',
     
     'SNDMORE',
 
@@ -177,6 +208,8 @@ base_names = [
     'UPSTREAM',
     'DOWNSTREAM',
     'STREAM',
+    'CLIENT',
+    'SERVER',
 
     # events
     'EVENT_CONNECTED',
@@ -199,7 +232,7 @@ base_names = [
     'GSSAPI',
 
     ## ERRNO
-    # Often used (these are alse in errno.)
+    # Often used (these are else in errno.)
     'EAGAIN',
     'EINVAL',
     'EFAULT',
@@ -215,7 +248,7 @@ base_names = [
     'EHOSTUNREACH',
     'ENETRESET',
 
-    # For Windows compatability
+    # For Windows compatibility
     'HAUSNUMERO',
     'ENOTSUP',
     'EPROTONOSUPPORT',
@@ -243,6 +276,11 @@ int64_sockopt_names = [
     'SWAP',
     'MCAST_LOOP',
     'RECOVERY_IVL_MSEC',
+
+    # new in 4.2
+    'VMCI_BUFFER_SIZE',
+    'VMCI_BUFFER_MIN_SIZE',
+    'VMCI_BUFFER_MAX_SIZE',
 ]
 
 bytes_sockopt_names = [
@@ -263,11 +301,12 @@ bytes_sockopt_names = [
     'GSSAPI_PRINCIPAL',
     'GSSAPI_SERVICE_PRINCIPAL',
     'SOCKS_PROXY',
+    
+    'XPUB_WELCOME_MSG',
 ]
 
 fd_sockopt_names = [
     'FD',
-    'IDENTITY_FD',
 ]
 
 int_sockopt_names = [
@@ -320,6 +359,21 @@ int_sockopt_names = [
     'GSSAPI_PLAINTEXT',
     'HANDSHAKE_IVL',
     'XPUB_NODROP',
+    
+    # new in 4.2
+    'XPUB_MANUAL',
+    'STREAM_NOTIFY',
+    'INVERT_MATCHING',
+    'XPUB_VERBOSER',
+    'HEARTBEAT_IVL',
+    'HEARTBEAT_TTL',
+    'HEARTBEAT_TIMEOUT',
+    'CONNECT_TIMEOUT',
+    'TCP_MAXRT',
+    'THREAD_SAFE',
+    'MULTICAST_MAXTPDU',
+    'VMCI_CONNECT_TIMEOUT',
+    'USE_FD',
 ]
 
 switched_sockopt_names = [
@@ -336,6 +390,7 @@ ctx_opt_names = [
     'SOCKET_LIMIT',
     'THREAD_PRIORITY',
     'THREAD_SCHED_POLICY',
+    'BLOCKY',
 ]
 
 msg_opt_names = [
